#!/usr/bin/python3
# more info on the M3U file format available here:
# http://n4k3d.com/the-m3u-file-format/

import sys
from lxml import etree
import urllib.parse

class channel():
    def __init__(self, id, title, path):
        self.id = id
        self.title = title
        self.path = path

"""
    channel info lines are formatted like:
    #EXTINF:-1,Das Erste HD
    #EXTVLCOPT:program=11100
    http://vuuno.wgr.local:8001/1:0:19:2B5C:41B:1:FFFF0000:0:0:0:
"""

def parsem3u(infile):
    try:
        assert(type(infile) == '_io.TextIOWrapper')
    except AssertionError:
        infile = open(infile,'r')

    """
        All M3U files start with #EXTM3U.
        If the first line doesn't start with this, we're either
        not working with an M3U or the file we got is corrupted.
    """

    line = infile.readline()
    if not line.startswith('#EXTM3U'):
       return

    # initialize playlist variables before reading file
    playlist=[]
    song=channel(None,None,None)

    for line in infile:
        line=line.strip()
        if line.startswith('#EXTINF:'):
            # pull length and title from #EXTINF line
            length,title=line.split('#EXTINF:')[1].split(',',1)
            song=channel(None,title,None)
        elif line.startswith('#EXTVLCOPT:program'):
            # pull program from #EXTVLCOPT line
            program=line.split('#EXTVLCOPT:')[1]
            song.id=program
        elif line.startswith('#EXTVLCOPT--'):
            # ignore
            pass
        elif (len(line) != 0):
            # pull song path from all other, non-blank lines
            song.path=line
            playlist.append(song)
            # reset the song variable so it doesn't use the same EXTINF more than once
            song=channel(None,None,None)

    infile.close()

    return playlist

# for now, just pull the track info and print it onscreen
# get the M3U file path from the first command line argument
def main():
    m3ufile=sys.argv[1]
    playlist = parsem3u(m3ufile)

    print ('<?xml version="1.0" encoding="UTF-8" ?>')
    root = etree.Element('onlineRepositoriesBackup')
    items = etree.SubElement(root, 'items')

    i = 1
    for track in playlist:
        item = etree.SubElement(items, 'backupItem', enabled="true", order=str(i))
        i += 1
        link = etree.SubElement(item, 'serviioLink')
        link.text = "serviio://video:live?url=" + urllib.parse.quote_plus(track.path) + "&name=" + urllib.parse.quote_plus(track.title)
        accgr = etree.SubElement(item, 'accessGroupIds')
        accid = etree.SubElement(accgr, 'id')
        accid.text = "1"
        #print (track.title, track.path)

    print (etree.tostring(root, encoding='utf8').decode('utf8'))

if __name__ == '__main__':
    main()

